--- linux.orig/include/linux/pci_ids.h	Tue Mar 21 15:04:53 2000
+++ linux/include/linux/pci_ids.h	Wed Apr  5 07:23:37 2000
@@ -788,9 +788,12 @@
 #define PCI_DEVICE_ID_RENDITION_VERITE	0x0001
 #define PCI_DEVICE_ID_RENDITION_VERITE2100 0x2000
 
-#define PCI_VENDOR_ID_RCC		0x1166
-#define PCI_DEVICE_ID_RCC_HE		0x0008
-#define PCI_DEVICE_ID_RCC_LE		0x0009
+#define PCI_VENDOR_ID_SERVERWORKS	0x1166
+#define PCI_DEVICE_ID_SERVERWORKS_HE	0x0008
+#define PCI_DEVICE_ID_SERVERWORKS_LE	0x0009
+#define PCI_DEVICE_ID_SERVERWORKS_CIOB30   0x0010
+#define PCI_DEVICE_ID_SERVERWORKS_CMIC_HE  0x0011
+#define PCI_DEVICE_ID_SERVERWORKS_CSB5	    0x0201
 
 #define PCI_VENDOR_ID_TOSHIBA		0x1179
 #define PCI_DEVICE_ID_TOSHIBA_601	0x0601
--- linux/drivers/pci/pci.ids.orig	Mon Mar 27 14:29:13 2000
+++ linux/drivers/pci/pci.ids	Mon May  1 13:19:12 2000
@@ -1774,9 +1774,12 @@
 1164  Advanced Peripherals Technologies
 1165  Imagraph Corporation
 	0001  Motion TPEG Recorder/Player with audio
-1166  Relience Computer
+1166  ServerWorks
 	0008  CNB20HE
-	0009  CNB20HE
+	0009  CNB20LE
+	0010  CIOB30
+	0011  CMIC_HE
+	0201  CSB5
 1167  Mutoh Industries Inc
 1168  Thine Electronics Inc
 1169  Centre for Development of Advanced Computing


--- linux/arch/i386/kernel/pci-pc.c.orig	Tue Apr 11 16:10:32 2000
+++ linux/arch/i386/kernel/pci-pc.c	Mon May  1 13:07:57 2000
@@ -841,15 +841,15 @@
 	pcibios_last_bus = -1;
 }
 
-static void __init pci_fixup_rcc(struct pci_dev *d)
+static void __init pci_fixup_serverworks(struct pci_dev *d)
 {
 	/*
 	 * RCC host bridges -- Find and scan all secondary buses.
 	 * Register 0x44 contains first, 0x45 last bus number routed there.
 	 */
 	u8 busno;
 	pci_read_config_byte(d, 0x44, &busno);
-	printk("PCI: RCC host bridge: secondary bus %02x\n", busno);
+	printk("PCI: ServerWorks host bridge: secondary bus %02x\n", busno);
 	pci_scan_bus(busno, pci_root_ops, NULL);
 	pcibios_last_bus = -1;
 }
@@ -915,8 +915,9 @@
 struct pci_fixup pcibios_fixups[] = {
 	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_INTEL,	PCI_DEVICE_ID_INTEL_82451NX,	pci_fixup_i450nx },
 	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_INTEL,	PCI_DEVICE_ID_INTEL_82454GX,	pci_fixup_i450gx },
-	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_RCC,	PCI_DEVICE_ID_RCC_HE,		pci_fixup_rcc },
-	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_RCC,	PCI_DEVICE_ID_RCC_LE,		pci_fixup_rcc },
+	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_SERVERWORKS,	PCI_DEVICE_ID_SERVERWORKS_HE,		pci_fixup_serverworks },
+	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_SERVERWORKS,	PCI_DEVICE_ID_SERVERWORKS_LE,		pci_fixup_serverworks },
+	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_SERVERWORKS,	PCI_DEVICE_ID_SERVERWORKS_CMIC_HE,	pci_fixup_serverworks },
 	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_COMPAQ,	PCI_DEVICE_ID_COMPAQ_6010,	pci_fixup_compaq },
 	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_UMC,	PCI_DEVICE_ID_UMC_UM8886BF,	pci_fixup_umc_ide },
 	{ PCI_FIXUP_HEADER,	PCI_VENDOR_ID_SI,	PCI_DEVICE_ID_SI_5513,		pci_fixup_ide_trash },
@@ -841,15 +841,15 @@
 {
 	/*
-	 * RCC host bridges -- Find and scan all secondary buses.
+	 * ServerWorks host bridges -- Find and scan all secondary buses.
 	 * Register 0x44 contains first, 0x45 last bus number routed there.
 	 */